@@ -5,26 +5,13 @@ use serde_json::Value;
 
 #[derive(FlowImpl)]
 /// Takes two arrays of values and produce an array of tuples of pairs of values from each input array.
-///
-/// ## Include using
-/// ```toml
-/// [[process]]
-/// alias = "zip"
-/// source = "lib://flowstdlib/data/zip"
-/// ```
-///
-/// ## Input
-/// * left - the 'left' array
-/// * right - the 'right' array
-///
-/// ## Outputs
-/// * tuples - the array of tuples of (left, right)
+#[derive(Debug)]
 pub struct Zip;
 
 impl Implementation for Zip {
-    fn run(&self, mut inputs: Vec<Vec<Value>>) -> (Option<Value>, RunAgain) {
-        let left = inputs.remove(0);
-        let right = inputs.remove(0);
+    fn run(&self, inputs: &[Value]) -> (Option<Value>, RunAgain) {
+        let left = &inputs[0].as_array().unwrap();
+        let right = &inputs[1].as_array().unwrap();
 
         let tuples = left.iter().zip(right.iter());
 
